pub fn reset_trace_cache()Expand description
Reset the cached trace value so that the next call to [is_trace] re-reads
the environment variable. Intended for use in tests.
pub fn reset_trace_cache()Reset the cached trace value so that the next call to [is_trace] re-reads
the environment variable. Intended for use in tests.